@@ -70,7 +70,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: pdmt.pl
 	PROJECT: meta
-	VERSION: 0.10
+	VERSION: 0.11
 
 =head1 SYNOPSIS
 
@@ -129,6 +129,10 @@ show license and exit
 
 show copyright and exit
 
+=item B<description> (type: bool, default: 0)
+
+show description and exit
+
 =item B<history> (type: bool, default: 0)
 
 show history and exit
@@ -165,6 +169,7 @@ None.
 	0.08 MV improve the movie db xml
 	0.09 MV web site automation
 	0.10 MV SEE ALSO section fix
+	0.11 MV move tests to modules
 
 =head1 SEE ALSO
 
