@@ -4,10 +4,10 @@ package Meta::Revision::Entry;
 
 use strict qw(vars refs subs);
 use Meta::Math::Pad qw();
-use Class::MethodMaker qw();
+use Meta::Class::MethodMaker qw();
 
 our($VERSION,@ISA);
-$VERSION="0.15";
+$VERSION="0.19";
 @ISA=qw();
 
 #sub BEGIN();
@@ -15,12 +15,13 @@ $VERSION="0.15";
 #sub printd($$);
 #sub string($);
 #sub perl_pod_line($$);
+#sub TEST($);
 
 #__DATA__
 
 sub BEGIN() {
-	Class::MethodMaker->new("new");
-	Class::MethodMaker->get_set(
+	Meta::Class::MethodMaker->new("new");
+	Meta::Class::MethodMaker->get_set(
 		-java=>"_number",
 		-java=>"_date",
 		-java=>"_initials",
@@ -77,6 +78,11 @@ sub perl_pod_line($$) {
 	return($retu);
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -110,7 +116,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Entry.pm
 	PROJECT: meta
-	VERSION: 0.15
+	VERSION: 0.19
 
 =head1 SYNOPSIS
 
@@ -139,6 +145,7 @@ in whatever.
 	printd($$)
 	string($)
 	perl_pod_line($$)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -177,8 +184,16 @@ entry.
 This method will return the revision entry in a manner suitable for insertion in
 a perl POD section.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -186,8 +201,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -208,10 +223,14 @@ None.
 	0.13 MV thumbnail project basics
 	0.14 MV thumbnail user interface
 	0.15 MV more thumbnail issues
+	0.16 MV website construction
+	0.17 MV web site development
+	0.18 MV web site automation
+	0.19 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Class::MethodMaker(3), Meta::Math::Pad(3), strict(3)
 
 =head1 TODO
 
