@@ -6,10 +6,11 @@ use strict qw(vars refs subs);
 use Meta::Baseline::Utils qw();
 
 our($VERSION,@ISA);
-$VERSION="0.08";
+$VERSION="0.11";
 @ISA=qw();
 
 #sub c2manx($);
+#sub TEST($);
 
 #__DATA__
 
@@ -19,6 +20,11 @@ sub c2manx($) {
 	return(1);
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -52,7 +58,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Docbook2.pm
 	PROJECT: meta
-	VERSION: 0.08
+	VERSION: 0.11
 
 =head1 SYNOPSIS
 
@@ -68,6 +74,7 @@ This job will make it easier to run the Docbook2 type tool.
 =head1 FUNCTIONS
 
 	c2manx($)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -77,8 +84,16 @@ This job will make it easier to run the Docbook2 type tool.
 
 This routine will convert sgml DocBook files to manual page format.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -86,8 +101,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -101,10 +116,13 @@ None.
 	0.06 MV movies and small fixes
 	0.07 MV thumbnail user interface
 	0.08 MV more thumbnail issues
+	0.09 MV website construction
+	0.10 MV web site automation
+	0.11 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Baseline::Utils(3), strict(3)
 
 =head1 TODO
 
