@@ -8,10 +8,11 @@ use Meta::Utils::Output qw();
 use Meta::Lang::Docb::Params qw();
 
 our($VERSION,@ISA);
-$VERSION="0.12";
+$VERSION="0.15";
 @ISA=qw();
 
 #sub dochec($);
+#sub TEST($);
 
 #__DATA__
 
@@ -71,6 +72,11 @@ sub dochec($) {
 	return($code);
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -104,7 +110,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Onsgmls.pm
 	PROJECT: meta
-	VERSION: 0.12
+	VERSION: 0.15
 
 =head1 SYNOPSIS
 
@@ -120,6 +126,7 @@ This module will ease the work of running onsgmls for you.
 =head1 FUNCTIONS
 
 	dochec($)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -130,8 +137,16 @@ This module will ease the work of running onsgmls for you.
 This method will check an sgml file using nsgmls and will return a boolean
 value according to whether that file is correct.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -139,8 +154,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -158,10 +173,13 @@ None.
 	0.10 MV movies and small fixes
 	0.11 MV thumbnail user interface
 	0.12 MV more thumbnail issues
+	0.13 MV website construction
+	0.14 MV web site automation
+	0.15 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Lang::Docb::Params(3), Meta::Utils::Output(3), Meta::Utils::System(3), strict(3)
 
 =head1 TODO
 
