@@ -6,13 +6,14 @@ use strict qw(vars refs subs);
 use Term::ANSIColor qw();
 
 our($VERSION,@ISA);
-$VERSION="0.23";
+$VERSION="0.26";
 @ISA=qw();
 
 #sub set_color($$);
 #sub get_color($);
 #sub get_reset();
 #sub reset($);
+#sub TEST($);
 
 #__DATA__
 
@@ -35,6 +36,11 @@ sub reset($) {
 	set_color($file,"reset");
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -68,7 +74,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Color.pm
 	PROJECT: meta
-	VERSION: 0.23
+	VERSION: 0.26
 
 =head1 SYNOPSIS
 
@@ -89,6 +95,7 @@ and texts.
 	get_color($)
 	get_reset()
 	reset($)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -113,8 +120,16 @@ the console.
 This resets the color to the regular color and avoids all kinds
 of weird side effects (for the file specified of course).
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -122,8 +137,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -152,10 +167,13 @@ None.
 	0.21 MV movies and small fixes
 	0.22 MV thumbnail user interface
 	0.23 MV more thumbnail issues
+	0.24 MV website construction
+	0.25 MV web site automation
+	0.26 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Term::ANSIColor(3), strict(3)
 
 =head1 TODO
 
