@@ -8,7 +8,7 @@ use Meta::Utils::System qw();
 use Meta::Utils::Output qw();
 
 our($VERSION,@ISA);
-$VERSION="0.10";
+$VERSION="0.13";
 @ISA=qw(Meta::Ds::Ohash);
 
 #sub new($);
@@ -51,6 +51,7 @@ $VERSION="0.10";
 #sub get_all_empty_dirs($$$);
 #sub print($$);
 #sub xml($$$);
+#sub TEST($);
 
 #__DATA__
 
@@ -487,6 +488,11 @@ sub xml($$$) {
 	$writ->endTag("fs");
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -520,7 +526,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Fs.pm
 	PROJECT: meta
-	VERSION: 0.10
+	VERSION: 0.13
 
 =head1 SYNOPSIS
 
@@ -590,6 +596,7 @@ a remote ftp server or the like...
 	get_all_empty_dirs($$$)
 	print($$)
 	xml($$$)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -813,8 +820,16 @@ don't want the print indented.
 This method receives an XML writer object and writer the file system into the XML
 writer object.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+Meta::Ds::Ohash(3)
+
 =head1 BUGS
 
 None.
@@ -822,8 +837,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -839,10 +854,13 @@ None.
 	0.08 MV movies and small fixes
 	0.09 MV thumbnail user interface
 	0.10 MV more thumbnail issues
+	0.11 MV website construction
+	0.12 MV web site automation
+	0.13 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Ds::Ohash(3), Meta::Utils::Output(3), Meta::Utils::System(3), strict(3)
 
 =head1 TODO
 
