@@ -5,10 +5,11 @@ package Meta::Utils::Text::Unique;
 use strict qw(vars refs subs);
 
 our($VERSION,@ISA);
-$VERSION="0.07";
+$VERSION="0.10";
 @ISA=qw();
 
 #sub filter($$);
+#sub TEST($);
 
 #__DATA__
 
@@ -23,6 +24,11 @@ sub filter($$) {
 	return(join($sepa,keys(%hash)));
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -56,7 +62,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Unique.pm
 	PROJECT: meta
-	VERSION: 0.07
+	VERSION: 0.10
 
 =head1 SYNOPSIS
 
@@ -73,6 +79,7 @@ lines (no repetitions).
 =head1 FUNCTIONS
 
 	filter($$)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -83,8 +90,16 @@ lines (no repetitions).
 This method gets some text with a delimiter and returns the same text
 with the same delimiter with only unique values in it.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -92,8 +107,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -106,10 +121,13 @@ None.
 	0.05 MV movies and small fixes
 	0.06 MV thumbnail user interface
 	0.07 MV more thumbnail issues
+	0.08 MV website construction
+	0.09 MV web site automation
+	0.10 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+strict(3)
 
 =head1 TODO
 
